@@ -68,11 +68,28 @@ class WorkflowDestinations(TSEnum):
     ENCLAVE = "ENCLAVE"
     UNKNOWN = "UNKNOWN"
 
+
 class ID_Types(TSEnum):
+
     INTERNAL = "INTERNAL"
     EXTERNAL = "EXTERNAL"
     UNRECOGNIZED = "UNRECOGNIZED"
 
+
 class ObservableSortColumns(TSEnum):
+
     FIRST_SEEN = "FIRST_SEEN"
     LAST_SEEN = "LAST_SEEN"
+
+
+class MaliciousScore(TSEnum):
+    BENIGN = "BENIGN"
+    LOW = "LOW"
+    MEDIUM = "MEDIUM"
+    HIGH = "HIGH"
+
+
+class ConfidenceScore(TSEnum):
+    LOW = "LOW"
+    MEDIUM = "MEDIUM"
+    HIGH = "HIGH"
